#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include "a_station.h"

// Создание пустой станции
struct station* create_station() {
    struct station* new_station = malloc(sizeof(struct station));
    if (!new_station) return NULL;

    new_station->tracks = calloc(STATION_SIZE, sizeof(struct car*));
    new_station->track_count = STATION_SIZE;
    return new_station;
}

// Освобождение памяти станции
void destroy_station(struct station* station) {
    for (int i = 0; i < station->track_count; i++) {
        struct car* current = station->tracks[i];
        while (current) {
            struct car* temp = current;
            current = current->next;
            free(temp);
        }
    }
    free(station->tracks);
    free(station);
}

// Хеш-функция для выбора пути
int select_track(struct station* station, const char* target) {
    unsigned int hash = 0;
    for (int i = 0; target[i] != '\0'; i++) {
        hash = (hash * 31 + target[i]);
    }
    return hash % station->track_count;
}

// Добавление или обновление записи для направления
void add_target_capacity(struct station* station, const char* target, int capacity) {
    int index = select_track(station, target);
    struct car* current = station->tracks[index];

    while (current) {
        if (strcmp(current->value, target) == 0) {
            current->capacity += capacity;
            return;
        }
        current = current->next;
    }

    struct car* new_car = malloc(sizeof(struct car));
    strncpy(new_car->value, target, TARGET_SIZE);
    new_car->value[TARGET_SIZE - 1] = '\0'; // Гарантия завершения строки
    new_car->capacity = capacity;
    new_car->next = station->tracks[index];
    station->tracks[index] = new_car;
}

// Получение ёмкости направления
int get_target_capacity(struct station* station, const char* target) {
    int index = select_track(station, target);
    struct car* current = station->tracks[index];

    while (current) {
        if (strcmp(current->value, target) == 0) {
            return current->capacity;
        }
        current = current->next;
    }
    return 0;
}

// Подсчёт количества направлений
int count_targets(struct station* station) {
    int count = 0;
    for (int i = 0; i < station->track_count; i++) {
        struct car* current = station->tracks[i];
        while (current) {
            count++;
            current = current->next;
        }
    }
    return count;
}

// Подсчёт общей ёмкости
int count_capacity(struct station* station) {
    int total_capacity = 0;
    for (int i = 0; i < station->track_count; i++) {
        struct car* current = station->tracks[i];
        while (current) {
            total_capacity += current->capacity;
            current = current->next;
        }
    }
    return total_capacity;
}

